Module dispatch

Module dispatch 

Unified types and version-aware decode/encode across drafts.

The Any* wrapper enums contain one variant per enabled draft feature. Enable multiple draft features (e.g. draft07 + draft14) for runtime dispatch between drafts. Unified types and version-aware decode/encode for runtime draft dispatch.

This module provides wrapper enums (Any*) that hold any enabled draft’s types and dispatch encoding/decoding based on DraftVersion.

Each enum variant is gated on its draft feature flag. Enable multiple draft features (e.g. draft07 + draft14) for runtime dispatch between drafts.

Re-exports

pub use crate::data_dispatch::reemit_subgroup_object;
pub use crate::data_dispatch::AnyFetchEndOfRange;
pub use crate::data_dispatch::AnyFetchFrame;
pub use crate::data_dispatch::AnyFetchGroupOrder;
pub use crate::data_dispatch::AnyFetchObject;
pub use crate::data_dispatch::AnyFetchObjectMeta;
pub use crate::data_dispatch::AnyFetchObjectReader;
pub use crate::data_dispatch::AnyFetchObjectWriter;
pub use crate::data_dispatch::AnySubgroupObject;
pub use crate::data_dispatch::AnySubgroupObjectMeta;
pub use crate::data_dispatch::AnySubgroupObjectReader;
pub use crate::data_dispatch::AnySubgroupObjectWriter;
pub use crate::data_dispatch::FetchReemit;
pub use crate::data_dispatch::Reemit;

Structs

AnyDatagramMeta
One datagram’s identity, resolved, without its payload.

Enums

AnyControlMessage
A control message from any enabled draft.
AnyDatagramHeader
A datagram header from any enabled draft.
AnyFetchHeader
A fetch header from any enabled draft.
AnyObjectHeader
An object header from any enabled draft.
AnySubgroupHeader
A subgroup header from any enabled draft.