FetchOk

Struct FetchOk 

pub struct FetchOk {
    pub request_id: VarInt,
    pub group_order: VarInt,
    pub end_of_track: VarInt,
    pub end_location: Location,
    pub parameters: Vec<KeyValuePair>,
}
FETCH_OK message (type 0x18).

Fields

request_id: VarInt

The request ID this response corresponds to.

group_order: VarInt

The group delivery order chosen by the publisher (VarInt).

end_of_track: VarInt

Whether the end of the track has been reached (VarInt).

end_location: Location

The end location of the fetch response.

parameters: Vec<KeyValuePair>

Response parameters (even/odd KVP encoding).