read_largest_location

Function read_largest_location 

fn read_largest_location(
    content_exists: ContentExists,
    buf: &mut impl Buf,
) -> Result<Option<Location>, CodecError>
Read the Largest Location that Content Exists says is there.

“This field is only present if Content Exists has a value of 1.”