FetchObject

Struct FetchObject 

pub struct FetchObject {
    pub group_id: VarInt,
    pub subgroup_id: VarInt,
    pub object_id: VarInt,
    pub publisher_priority: u8,
    pub extension_headers: Vec<u8>,
    pub status: Option<ObjectStatus>,
    pub payload: Vec<u8>,
}
One object carried on a fetch stream (10.4.4, Figure 35).

Every object on a fetch stream is self-describing — unlike subgroup streams, there is no delta encoding and extension headers are always length-prefixed (the length is zero when absent).

Fields

group_id: VarInt

Group ID.

subgroup_id: VarInt

Subgroup ID. For objects whose Forwarding Preference is Datagram, this is set to the Object ID.

object_id: VarInt

Object ID.

publisher_priority: u8

Publisher priority.

extension_headers: Vec<u8>

Raw extension-header bytes (opaque sequence of Key-Value-Pairs).

status: Option<ObjectStatus>

Object status when payload.is_empty(), otherwise None.

payload: Vec<u8>

Object payload.

Implementations

Source

impl FetchObject

pub fn encode(&self, buf: &mut impl BufMut)

Encode one fetch object.

pub fn decode(buf: &mut impl Buf) -> Result<Self, CodecError>

Decode one fetch object.