Module types

Module types 

Draft-14 specific types (object status, etc.). Draft-14 specific types.

Types in this module are specific to draft-14 wire values and are kept separate from the shared crate::types module so that other drafts can continue to use their own enums without collision.

Enums

ObjectStatus
Object status values, from MoQ Transport draft-14 Section 10.2.1.1 “Object Status”.