pub fn kvp_to_json_d08_setup(params: &[KeyValuePair]) -> FieldValueExpand description
The setup parameter list of a draft that dropped ROLE.
pub fn kvp_to_json_d08_setup(params: &[KeyValuePair]) -> FieldValueThe setup parameter list of a draft that dropped ROLE.