#[repr(u64)]pub enum StreamType {
Show 13 variants
Fetch = 5,
SubgroupZero = 16,
SubgroupZeroExt = 17,
SubgroupFirstObj = 18,
SubgroupFirstObjExt = 19,
SubgroupExplicit = 20,
SubgroupExplicitExt = 21,
SubgroupZeroEog = 24,
SubgroupZeroEogExt = 25,
SubgroupFirstObjEog = 26,
SubgroupFirstObjEogExt = 27,
SubgroupExplicitEog = 28,
SubgroupExplicitEogExt = 29,
}Expand description
Stream type IDs for draft-12 data streams.
Variants
Fetch = 5
Fetch response stream (0x05).
SubgroupZero = 16
Subgroup: subgroup_id=0, no extensions (0x10).
SubgroupZeroExt = 17
Subgroup: subgroup_id=0, with extensions (0x11).
SubgroupFirstObj = 18
Subgroup: subgroup_id=first object ID, no extensions (0x12).
SubgroupFirstObjExt = 19
Subgroup: subgroup_id=first object ID, with extensions (0x13).
SubgroupExplicit = 20
Subgroup: explicit subgroup_id, no extensions (0x14).
SubgroupExplicitExt = 21
Subgroup: explicit subgroup_id, with extensions (0x15).
SubgroupZeroEog = 24
Subgroup: subgroup_id=0, contains end of group, no extensions (0x18).
SubgroupZeroEogExt = 25
Subgroup: subgroup_id=0, contains end of group, with extensions (0x19).
SubgroupFirstObjEog = 26
Subgroup: subgroup_id=first object ID, contains end of group, no extensions (0x1A).
SubgroupFirstObjEogExt = 27
Subgroup: subgroup_id=first object ID, contains end of group, with extensions (0x1B).
SubgroupExplicitEog = 28
Subgroup: explicit subgroup_id, contains end of group, no extensions (0x1C).
SubgroupExplicitEogExt = 29
Subgroup: explicit subgroup_id, contains end of group, with extensions (0x1D).
Implementations
Sourceimpl StreamType
impl StreamType
pub fn from_id(id: u64) -> Option<Self>
pub fn is_subgroup(&self) -> bool
pub fn has_extensions(&self) -> bool
Sourcepub fn contains_end_of_group(&self) -> bool
pub fn contains_end_of_group(&self) -> bool
True if this subgroup stream type indicates the stream contains the end of its group.
Sourcepub fn writes_subgroup_id(&self) -> bool
pub fn writes_subgroup_id(&self) -> bool
True if this subgroup stream type puts an explicit Subgroup ID on the wire.
The Subgroup ID Field Present column of the SUBGROUP_HEADER type table in Section 9.4.2. The other two columns of that row say what the Subgroup ID is where the field is absent — zero, or the first Object’s ID — so this is only about the field, never about the value.