DatagramHeader

Struct DatagramHeader 

pub struct DatagramHeader {
    pub datagram_type: u8,
    pub track_alias: VarInt,
    pub group_id: VarInt,
    pub object_id: VarInt,
    pub publisher_priority: Option<u8>,
    pub extension_headers: Vec<u8>,
    pub object_status: Option<VarInt>,
}

Fields

datagram_type: u8track_alias: VarIntgroup_id: VarIntobject_id: VarIntpublisher_priority: Option<u8>

Publisher priority — None when the DEFAULT_PRIORITY flag is set and the priority is inherited from the subscription’s control message.

extension_headers: Vec<u8>

Opaque extension-headers blob (only when flag 0x01 is set).

object_status: Option<VarInt>

Implementations

Source

impl DatagramHeader

pub fn has_extensions(&self) -> bool

pub fn is_end_of_group(&self) -> bool

pub fn has_object_id(&self) -> bool

pub fn has_default_priority(&self) -> bool

When set, publisher_priority is omitted on the wire and inherited from the subscription / control-message context.

pub fn is_status(&self) -> bool

pub fn encode(&self, buf: &mut impl BufMut)

pub fn decode(buf: &mut impl Buf) -> Result<Self, CodecError>