REQUEST_ERROR error codes with dedicated meaning.
Note: DUPLICATE_SUBSCRIPTION (0x19) is removed in draft-19, as multiple concurrent subscriptions per Track are now allowed.
Constants
- CONFLICTING_
FILTERS - New in draft-19: SUBSCRIBE_TRACKS filter parameters conflict among too many subscribers to aggregate the subscription upstream.
- INVALID_
FILTER - New in draft-19: a Range Filter parameter is invalid or exceeds MAX_FILTER_RANGES.
- REDIRECT
- Response carries a
super::Redirectstructure. - UNSUPPORTED_
EXTENSION - A Mandatory Track Property the receiver does not understand.